##  Miscellaneous
  1. Governing Law. You agree that these Application Terms and your use of the Application are governed under Massachusetts law, and any dispute related to the Application must be brought in a tribunal of competent jurisdiction located in or near Boston, Massachusetts.
